@@ -19,7 +19,7 @@ this program; if not, see <http://www.gnu.org/licenses/>.
 
 #include <fstream>
 #include <stdint.h>
-
+#include <iostream>
 #include <octave/oct.h>
 #include <octave/parse.h>
 #include <octave/Cell.h>
@@ -46,12 +46,12 @@ This is a helper IO function for the @qcode{table2csv} method of the \
   }
 
   // Get input arguments
-  string file = args(0).string_value();
-  Cell C = args(1).cell_value();
+  string file = args(0).string_value ();
+  Cell C = args(1).cell_value ();
 
   // Open CSV file
-  ofstream fd(file.c_str());
-  if (! fd.is_open())
+  ofstream fd(file.c_str ());
+  if (! fd.is_open ())
   {
     retval(0) = "cannot open file '" + file + "' for writing.";
     return retval;
@@ -61,8 +61,8 @@ This is a helper IO function for the @qcode{table2csv} method of the \
   string word;
   string sep = ",";
   string prot = "\"";
-  int rows = C.rows();
-  int cols = C.columns();
+  int rows = C.rows ();
+  int cols = C.columns ();
 
   // Process each row
   for (int row = 0; row < rows; row++)
@@ -79,17 +79,30 @@ This is a helper IO function for the @qcode{table2csv} method of the \
       }
 
       // Real numeric values
-      if (C(row, col).is_real_scalar())
+      if (C(row, col).is_real_scalar ())
       {
-        char tmp[30];
-        sprintf(tmp, "%.15g", C(row, col).double_value());
-        word += tmp;
+        double value = C(row, col).double_value ();
+        // Handle NaN first
+        if (octave::math::isna (value))
+        {
+          word += "NA";
+        }
+        else if (isnan (value))
+        {
+          word += "NaN";
+        }
+        else
+        {
+          char tmp[30];
+          sprintf(tmp, "%.15g", value);
+          word += tmp;
+        }
       }
 
       // String values
-      else if (C(row, col).is_string())
+      else if (C(row, col).is_string ())
       {
-        string str = C(row, col).string_value();
+        string str = C(row, col).string_value ();
         str = prot + str + prot;
         word += str;
       }
